#include <DHT.h>
#include <ESP8266WiFi.h>
#include <ESP8266HTTPClient.h>

#define DHTPIN D4  // Pino de leitura do DHT11
#define DHTTYPE DHT11  // Define o tipo de sensor DHT

DHT dht(DHTPIN, DHTTYPE);

// Definindo os pinos para os LEDs
int whitePin = D6;  // LED branco
int redPin = D7;    // LED vermelho

// Configuração da rede Wi-Fi
const char* ssid = "arduino";
const char* password = "meuarduino";

WiFiClient client;  // Instancia o WiFiClient

void setup() {
  pinMode(whitePin, OUTPUT);
  pinMode(redPin, OUTPUT);
  digitalWrite(whitePin, LOW);
  digitalWrite(redPin, LOW);

  dht.begin();
  
  Serial.begin(921600);
  
  Serial.print("Conectando ao WiFi");
  WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(1000);
    Serial.print(".");
  }
  Serial.println(" Conectado!");
  Serial.print("IP Address: ");
  Serial.println(WiFi.localIP());
}

void loop() {
  float h = dht.readHumidity();
  float t = dht.readTemperature();
  
  if (isnan(h) || isnan(t)) {
    Serial.println("Falha na leitura do DHT11!");
  } else {
    Serial.print("Umidade: ");
    Serial.print(h);
    Serial.print("%  ");
    Serial.print("Temperatura: ");
    Serial.print(t);
    Serial.println("°C");

    if (WiFi.status() == WL_CONNECTED) {
      HTTPClient http;
      String url = "https://davidpezzin.com.br/projetos/sensoreamento/insere.php?d1=" + String(h) + "&d2=" + String(t);
      Serial.println("URL: " + url);  // Imprime a URL para depuração

      http.begin(client, url);

      int httpCode = http.GET();
      Serial.print("HTTP Code: ");
      Serial.println(httpCode);  // Imprime o código HTTP

      if (httpCode == HTTP_CODE_OK) {
        String payload = http.getString();
        Serial.println("Resposta do servidor: " + payload);
      } else {
        Serial.println("Erro na requisição GET, código: " + String(httpCode));
      }
      http.end();
    } else {
      Serial.println("Não conectado ao WiFi");
    }

    if (t >= 27) {
      digitalWrite(redPin, HIGH);
      digitalWrite(whitePin, LOW);
    } else {
      digitalWrite(redPin, LOW);
      digitalWrite(whitePin, HIGH);
      delay(500);
      digitalWrite(whitePin, LOW);
      delay(500);
    }
  }

  delay(1000);
}
